@@ -34,43 +34,62 @@ sleep "`cat /home/user/.config/savepress | grep "vdelay" | sed 's/vdelay: //g' |
 if [ `hal-get-property --udi /org/freedesktop/Hal/devices/platform_kb_lock --key button.state.value` == true ]; then {
 	echo "button pressed.."
 	if [ -f /tmp/savepress ]; then {
-		echo "disabling.."
-		/usr/sbin/kernel-config limits `cat /tmp/savepress-value | grep "min" | sed 's/min: //g'` `cat /tmp/savepress-value | grep "max" | sed 's/max: //g'`
 		dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:"unlocked"
+		run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"savepress is disabled!"
+		echo "  disabling.."
+		if [ "`cat /tmp/savepress-value | grep "lock"`" == "lock" ]; then {
+#			/usr/sbin/kernel-config unlock
+			/usr/sbin/kernel-config load savepress-tmp
+			rm /home/user/.kernel/savepress-tmp
+			echo "    rm /home/user/.kernel/savepress-tmp"
+			}
+		else {
+			/usr/sbin/kernel-config limits `cat /tmp/savepress-value | grep "min" | sed 's/min: //g'` `cat /tmp/savepress-value | grep "max" | sed 's/max: //g'`
+			}
+		fi
 		rm /tmp/savepress
+		echo "    rm /tmp/savpress"
 	
 		# restore settings
 		if [ "`cat /tmp/savepress-value | grep "offline"`" != "" ]; then {
 			dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:"normal"
+			echo "    enabled cellular radio"
 			}
 		fi
 		if [ "`cat /tmp/savepress-value | grep "wlan-dis"`" != "" ]; then {
 			dbus-send --system --type=method_call --dest=com.nokia.icd /com/nokia/icd com.nokia.icd.connect string:"[ANY]" uint32:0
+			echo "    searching new wlan"
 			}
 		fi
 		if [ "`cat /tmp/savepress-value | grep "mode" | sed 's/mode: //g'`" != "" ]; then {
 			dbus-send --system --type=method_call --dest=com.nokia.phone.net /com/nokia/phone/net Phone.Net.set_selected_radio_access_technology byte:"`cat /tmp/savepress-value | grep "mode" | sed 's/mode: //g'`"
+			echo "   disabled gsm-only"
 			}
 		fi
-		run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"savepress is disabled!"
 		rm /tmp/savepress-value
+		echo "    rm /tmp/savepress-value"
 		}
 	else {
-		echo "activating.."
+		echo "  activating.."
 		dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:"unlocked"
+		run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"savepress is activated!"
 		echo "on" > /tmp/savepress
+		echo "    created /tmp/savepress"
 	
 		# activate settings
-		echo "`/usr/sbin/kernel-config show | grep "max" | sed 's/. frequency//g'`" > /tmp/savepress-value
-		echo "`/usr/sbin/kernel-config show | grep "min" | sed 's/. frequency//g'`" >> /tmp/savepress-value
 		if [ "`cat /home/user/.config/savepress | grep "vwlan" | sed 's/vwlan: //g' | sed 's/ //g'`" == "True" ]; then {
 			dbus-send --system --dest=com.nokia.icd /com/nokia/icd_ui com.nokia.icd_ui.disconnect boolean:true
-			echo "wlan-dis" >> /tmp/savepress-value
+			if [ -f /var/run/resolv.conf.wlan0 ]; then {
+				echo "wlan-dis" >> /tmp/savepress-value
+				echo "    disabled wlan"
+				}
+			fi
 			}
 		fi
 		
 		if [ "`cat /home/user/.config/savepress | grep "vblue" | sed 's/vblue: //g' | sed 's/ //g'`" == "True" ]; then {
 			dbus-send --system --type=method_call --dest=org.bluez $(dbus-send --system --print-reply --dest=org.bluez / org.bluez.Manager.ListAdapters | awk -F "\"" '/at/ {print $2}') org.bluez.Adapter.SetProperty string:Powered variant:boolean:false
+			echo "    disconnected bluetooth"
 			}
 		fi
 
@@ -78,6 +97,7 @@ if [ `hal-get-property --udi /org/freedesktop/Hal/devices/platform_kb_lock --key
 			if [ "`dbus-send --print-reply --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.get_device_mode | grep -o normal`" == "normal" ]; then {
 				dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:"offline"
 				echo "offline" >> /tmp/savepress-value
+				echo "    disabled cellular radio"
 				}
 			fi
 			}
@@ -87,19 +107,30 @@ if [ `hal-get-property --udi /org/freedesktop/Hal/devices/platform_kb_lock --key
 				if [ "$netmode" != "1" ]; then {
 					echo "mode: $netmode" >> /tmp/savepress-value
 					dbus-send --system --type=method_call --dest=com.nokia.phone.net /com/nokia/phone/net Phone.Net.set_selected_radio_access_technology byte:1
+					echo "    enabled gsm-only"
 					}
 				fi
 				}
 			fi
 			}
 		fi
-		run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"savepress is activated!"
 		sleep 1
 		dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:"locked"
-		/usr/sbin/kernel-config limits `cat /home/user/.config/savepress | grep "vmin" | sed 's/vmin: //g' | sed 's/ //g'` `cat /home/user/.config/savepress | grep "vmax" | sed 's/vmax: //g' | sed 's/ //g'`
+
+		if [ "`cat /home/user/.config/savepress | grep "vlock:" | sed 's/vlock: //g' | sed 's/ //g'`" == "True" ]; then {
+			echo "lock" >> /tmp/savepress-value
+			/usr/sbin/kernel-config save savepress-tmp
+			/usr/sbin/kernel-config lock `cat /home/user/.config/savepress | grep "vmhz:" | sed 's/vmhz: //g' | sed 's/ //g'` `cat /home/user/.config/savepress | grep "vvolt:" | sed 's/vvolt: //g' | sed 's/ //g'` `cat /home/user/.config/savepress | grep "vdsp:" | sed 's/vdsp: //g' | sed 's/ //g'`
+			}
+		else {
+			echo "`/usr/sbin/kernel-config show | grep "max" | sed 's/. frequency//g'`" >> /tmp/savepress-value
+			echo "`/usr/sbin/kernel-config show | grep "min" | sed 's/. frequency//g'`" >> /tmp/savepress-value
+			/usr/sbin/kernel-config limits `cat /home/user/.config/savepress | grep "vmin" | sed 's/vmin: //g' | sed 's/ //g'` `cat /home/user/.config/savepress | grep "vmax" | sed 's/vmax: //g' | sed 's/ //g'`
+			}
+		fi
 		}
 	fi
-	echo "done.."
+	echo "  done.."
 	}
 else {
 	echo "not pressed.."
